@@ -27,8 +27,7 @@ OPTS = [
     cfg.StrOpt('hypervisor_inspector',
                default='libvirt',
                help='Inspector to use for inspecting the hypervisor layer. '
-                    'Known inspectors are libvirt, hyperv, vsphere '
-                    'and xenapi. Note that xenapi has been deprecated.'),
+                    'Known inspectors are libvirt and vsphere.'),
 ]
 
 
@@ -130,21 +129,6 @@ DiskRateStats = collections.namedtuple('DiskRateStats',
                                         'write_bytes_rate',
                                         'write_requests_rate'])
 
-# Named tuple representing disk latency statistics.
-#
-# disk_latency: average disk latency
-#
-DiskLatencyStats = collections.namedtuple('DiskLatencyStats',
-                                          ['device', 'disk_latency'])
-
-# Named tuple representing disk iops statistics.
-#
-# iops: number of iops per second
-#
-DiskIOPSStats = collections.namedtuple('DiskIOPSStats',
-                                       ['device', 'iops_count'])
-
-
 # Named tuple representing disk Information.
 #
 # capacity: capacity of the disk
@@ -238,26 +222,6 @@ class Inspector(object):
         """
         raise ceilometer.NotImplementedError
 
-    def inspect_disk_latency(self, instance, duration):
-        """Inspect the disk statistics as rates for an instance.
-
-        :param instance: the target instance
-        :param duration: the last 'n' seconds, over which the value should be
-               inspected
-        :return: for each disk, the average disk latency
-        """
-        raise ceilometer.NotImplementedError
-
-    def inspect_disk_iops(self, instance, duration):
-        """Inspect the disk statistics as rates for an instance.
-
-        :param instance: the target instance
-        :param duration: the last 'n' seconds, over which the value should be
-               inspected
-        :return: for each disk, the number of iops per second
-        """
-        raise ceilometer.NotImplementedError
-
     def inspect_disk_info(self, instance, duration):
         """Inspect the disk information for an instance.
 
@@ -270,9 +234,6 @@ class Inspector(object):
 
 
 def get_hypervisor_inspector(conf):
-    if conf.hypervisor_inspector == 'xenapi':
-        LOG.warning('Support for XenServer/Xen Cloud Platform has been '
-                    'deprecated and will be removed in a future release')
     try:
         namespace = 'ceilometer.compute.virt'
         mgr = driver.DriverManager(namespace,
